Use-cases
=========
Below are some examples on how to use PSO in different applications. 
If you wish to check the actual Jupyter Notebooks, please go to this `link <https://github.com/ljvmiranda921/pyswarms/tree/master/examples>`_

.. toctree::

   feature_subset_selection
   inverse_kinematics
